@@ -39,12 +39,13 @@ from __future__ import annotations
 
 # Standard Library
 from argparse import ArgumentParser, _ArgumentGroup  # noqa: WPS450
+from dataclasses import asdict
 
 # Types
-from typing import Any, Generator, MutableMapping, Optional, Union
+from typing import Any, Generator, MutableMapping, Optional, Type, Union
 
 # Local
-from .utils import add_prefix
+from .utils import DC, add_prefix, from_dict
 
 
 def _iter_config(
@@ -99,6 +100,12 @@ class ConfigDict(MutableMapping):
             return ConfigDict(res)
         return res
 
+    def __setstate__(self, state: dict):
+        """Restore state."""
+        data = state.pop("_ConfigDict__data")
+        self.__dict__.update(state)
+        self.__data = data
+
     def __iter__(self) -> Generator[tuple[str, Any], None, None]:
         """Generate config items."""
         yield from self.__data.items()
@@ -132,6 +139,19 @@ class Option:
         self.args = args
         self.kwds = kwds
 
+    def __repr__(self) -> str:
+        """Repr options."""
+        args = ", ".join(self.args)
+        kwds = ", ".join(
+            map(
+                lambda x: "=".join(
+                    map(lambda s: "'" in str(s) and str(s) or repr(s), x)
+                ),
+                self.kwds.items(),
+            )
+        )
+        return f"Option({args and f'{args}, *, ' or ''}{kwds}"
+
 
 class Config:
     """Smile config."""
@@ -140,6 +160,7 @@ class Config:
         self,
         help_: Union[Option, str] = "Smile Config help info.",
         *options: Union[Option, SConfig],
+        dcls: Optional[Type[DC]] = None,
     ) -> None:
         """Initialize."""
         if isinstance(help_, str):
@@ -147,7 +168,11 @@ class Config:
         else:
             self.help = help_
         self.options = options
-        self.config = ConfigDict(vars(self.build().parse_args()))
+        config = vars(self.build().parse_args())
+        if dcls is not None:
+            self.config = from_dict(dcls, config)
+        else:
+            self.config = ConfigDict(config)
 
     def build(self):
         """Post initialize."""
@@ -160,14 +185,17 @@ class Config:
 
     def __getattr__(self, name: str) -> Any:
         """Get attr from config."""
-        try:
+        if name == "config":
+            return super().__getattribute__(name)  # noqa: WPS613
+        if name in asdict(self.config).keys():
             return getattr(self.config, name)
-        except AttributeError:
-            return object.__getattribute__(self, name)  # noqa: WPS609
+        return super().__getattribute__(name)  # noqa: WPS613
 
     def __repr__(self) -> str:
         """Repr str."""
-        return str(self.config)
+        if "config" in self.__dict__:
+            return str(self.config)
+        return str(vars(self))
 
     def __dir__(self) -> list[str]:
         """Dir self."""
